@@ -116,6 +116,7 @@ class MaxClient(ApiMixin, WebSocketMixin, BaseClient):
         self.dialogs: list[Dialog] = []
         self.channels: list[Channel] = []
         self.me: Me | None = None
+        self.contacts: list[User] = []
         self._users: dict[int, User] = {}
 
         self._work_dir: str = work_dir
@@ -295,7 +296,7 @@ class MaxClient(ApiMixin, WebSocketMixin, BaseClient):
                 if self._token is None:
                     await self._login()
 
-                await self._sync()
+                await self._sync(self.user_agent)
 
                 await self._post_login_tasks(sync=False)
 
